Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(19)

Unified Diff: src/utils/SkTextureCompressor.h

Issue 417933005: Add preliminary ASTC encoder (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: Code review changes Created 6 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « gyp/utils.gypi ('k') | src/utils/SkTextureCompressor.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/utils/SkTextureCompressor.h
diff --git a/src/utils/SkTextureCompressor.h b/src/utils/SkTextureCompressor.h
index a7afe0384b041f196b3bccb4baf1d66e32241d34..5238ba221be035c78d118b78346dee5fc788f0d6 100644
--- a/src/utils/SkTextureCompressor.h
+++ b/src/utils/SkTextureCompressor.h
@@ -18,10 +18,11 @@ namespace SkTextureCompressor {
// Various texture compression formats that we support.
enum Format {
// Alpha only formats.
- kLATC_Format, // 4x4 blocks, compresses A8
- kR11_EAC_Format, // 4x4 blocks, compresses A8
+ kLATC_Format, // 4x4 blocks, compresses A8
+ kR11_EAC_Format, // 4x4 blocks, compresses A8
+ kASTC_12x12_Format, // 12x12 blocks, compresses A8
- kLast_Format = kR11_EAC_Format
+ kLast_Format = kASTC_12x12_Format
};
static const int kFormatCnt = kLast_Format + 1;
« no previous file with comments | « gyp/utils.gypi ('k') | src/utils/SkTextureCompressor.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698